CargoCrate

Struct CargoCrate 

pub struct CargoCrate {
    pub doc: Document,
    pub path: PathBuf,
    pub dependencies: Vec<Dependency>,
}
Initial representation of a crate, before being parsed

Fields

doc: Documentpath: PathBufdependencies: Vec<Dependency>

Implementations

Source

impl CargoCrate

pub fn name(&self) -> String

Get the crate name from the inner document

pub fn version(&self) -> String

Get the current version

pub fn dep_by_name(&self, name: &String) -> &Dependency

Find a cargo dependency by name

pub fn change_dep(&mut self, dep: &String, ver: &String)

pub fn all_deps_mut(&mut self) -> Vec<&mut Dependency>

pub fn has_version(&self, name: &String) -> bool

Check if this crate depends on a specific version of another

pub fn has_path(&self, name: &String) -> bool

Check if this crate depends on a specific path of another

pub fn set_version(&mut self, version: String)

Set a new version for this crate

pub fn sync(&mut self)

Sync any changes made to the document to disk