Crate

Struct Crate 

pub struct Crate {
    pub id: CrateId,
    pub name: String,
    pub cc: CargoCrate,
    pub dependencies: BTreeSet<CrateId>,
}
A crate in a cargo workspace

Has a name, path (stored as the offset of the root), and set of dependencies inside the workspace. To get the dependents of this crate, query the dependency graph with the set of other crate IDs.

Fields

id: CrateId

Numeric Id of this crate

name: String

Package name, not the folder name

cc: CargoCrate

Path offset of the workspace root

dependencies: BTreeSet<CrateId>

List of dependencies this crate has inside this workspace

Implementations

Source

impl Crate

pub fn new(cc: CargoCrate) -> Self

pub fn process(&mut self, g: &DepGraph)

Call this function once all crates have been loaded into scope

pub fn name(&self) -> &String

Get the crate name

pub fn path(&self) -> &PathBuf

Get the crate path

pub fn version(&self) -> String

Get the current version

pub fn add_dependency(&mut self, id: CrateId)

Add a dependency of this crate

pub fn has_dependency(&self, id: CrateId) -> bool

Check if this crate has a particular dependency

pub fn change_dependency(&mut self, dep: &String, new_ver: &String)

pub fn publish(&mut self, new_version: String)

Publish a new version of this crate

pub fn sync(&mut self)