pub struct CargoCrate {
pub doc: Document,
pub path: PathBuf,
pub dependencies: Vec<Dependency>,
}Expand description
Initial representation of a crate, before being parsed
Fields
doc: Documentpath: PathBufdependencies: Vec<Dependency>Implementations
Sourceimpl CargoCrate
impl CargoCrate
Sourcepub fn dep_by_name(&self, name: &String) -> &Dependency
pub fn dep_by_name(&self, name: &String) -> &Dependency
Find a cargo dependency by name
pub fn change_dep(&mut self, dep: &String, ver: &String)
pub fn all_deps_mut(&mut self) -> Vec<&mut Dependency>
Sourcepub fn has_version(&self, name: &String) -> bool
pub fn has_version(&self, name: &String) -> bool
Check if this crate depends on a specific version of another
Sourcepub fn has_path(&self, name: &String) -> bool
pub fn has_path(&self, name: &String) -> bool
Check if this crate depends on a specific path of another
Sourcepub fn set_version(&mut self, version: String)
pub fn set_version(&mut self, version: String)
Set a new version for this crate